function varargout = DLA_GUI(varargin)
% DLA_GUI M-file for DLA_GUI.fig
%      DLA_GUI, by itself, creates a new DLA_GUI or raises the existing
%      singleton*.
%
%      H = DLA_GUI returns the handle to a new DLA_GUI or the handle to
%      the existing singleton*.
%
%      DLA_GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DLA_GUI.M with the given input arguments.
%
%      DLA_GUI('Property','Value',...) creates a new DLA_GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before DLA_GUI_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to DLA_GUI_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help DLA_GUI

% Last Modified by GUIDE v2.5 01-Jul-2008 11:20:11

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @DLA_GUI_OpeningFcn, ...
                   'gui_OutputFcn',  @DLA_GUI_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before DLA_GUI is made visible.
function DLA_GUI_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to DLA_GUI (see VARARGIN)

% Choose default command line output for DLA_GUI
handles.output = hObject;

%set A matrix to zeros
set(handles.A_Matrix_Table,'Data', zeros(5));

% Update handles structure
guidata(hObject, handles);

% --- Outputs from this function are returned to the command line.
function varargout = DLA_GUI_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in Set_Matrix_Size_Button.
function Set_Size_Of_Matrix_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Set_Matrix_Size_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

size = str2double(get(handles.A_Matrix_Size_Textbox, 'String'));

size = floor(size);

if (size >= 2 && size <= 100)
    set(handles.A_Matrix_Table,'Data', zeros(size));
else
    errordlg('Matrix size must be greater than 2 and less than 100', 'Error')
end
    
guidata(hObject, handles);


% --- Executes on button press in Go_Button.
function Go_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Go_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

set(handles.Unique_Decomp_Panel, 'Visible', 'off');
set(handles.Eigen_Analysis_Panel, 'Visible', 'off');
set(handles.Loops_Panel, 'Visible', 'off');
set(handles.Loop_Elas_Panel, 'Visible', 'off');
set(handles.Optimization_Panel, 'Visible', 'off');

set(handles.Loops_List_Listbox, 'Value', 1);

A = get(handles.A_Matrix_Table, 'Data')

%to correct for if user fails to hit enter after typing in value
set(handles.A_Matrix_Table, 'Data', [])
%rewrite back so user knows what data got run
set(handles.A_Matrix_Table, 'Data', A)

guidata(hObject, handles);

% Check that the number of rows equals the number of columns. If not,
% terminate execution of the program.
[nr,nc]=size(A);
if nr~=nc 
    fprintf('A is not a square matrix.')
    fprintf('\n')
    errordlg('A is not a square matrix.', 'Error');
    return
end
Num_Nodes = nr;  % The number of stages is n. 

% This program is designed for use with strongly connected life cycle
% graphs, i.e., the population projection matrix A must be irreducible.

% Check that A is irreducible.  (A need not be primitive.)
% A is irreducible if and only if (A+I)^(n-1) has no zeros.
AI=A;
for j = 1 : Num_Nodes
    AI(j,j)=AI(j,j)+1;
end

if (nnz(AI^(Num_Nodes-1)) < Num_Nodes^2)
    fprintf('A is a reducible matrix.')
    fprintf('\n')
    errordlg('A is a reducible matrix.', 'Error');
    return
end

if (~isempty(find(A<0)))
    fprintf('A must be non-negative')
    errordlg('A must be non-negative', 'Error');
    return
end

fid = fopen('DLA_GUI_Output.txt', 'w');
fprintf(fid, 'A = \n');
dlmwrite('DLA_GUI_Output.txt', A, 'precision', ' %.6f', '-append');

nzA = find(A~=0); % Get locations of nonzero elements of A.
Num_Edges = length(nzA);  % Number of nonzero entries of A = number of edges 
                % in the life-cycle graph.

% Now find the dominant eigenvalue Lambda of A (largest real) and the 
% associated left and right eigenvectors of Lambda, scaled to give the 
% reproductive value and stable age distribution respectively. 

% By finding the eigenvalue with maximum real part, we avoid problems that
% arose during testing on imprimitive matrices.

[V,D]=eig(full(A));   
[Lambda,Lambda_index]=max(max(real(D))); 
Right_EV= V(:,Lambda_index);       % This will give the stable stage distribution.
Right_EV=Right_EV / sum(Right_EV); % Rescale so components sum to 1.

set(handles.Right_EV_Table, 'Data', Right_EV);
set(handles.Lambda_Textbox, 'String', Lambda);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nLambda = \n');
dlmwrite('DLA_GUI_Output.txt', Lambda, 'precision', ' %.6f', '-append');
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nStable Stage Distribution (Right Eigenvector) = \n');
dlmwrite('DLA_GUI_Output.txt', Right_EV, 'precision', ' %.6f', '-append');

 
[V,D]=eig(full(A'));  
[Lambda,Lambda_index]=max(max(real(D)));
Left_EV= V(:,Lambda_index);      % This will give the reproductive value.
Left_EV=Left_EV / Left_EV(1,1);  % Rescale so first component = 1.

set(handles.Left_EV_Table, 'Data', Left_EV);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nReproductive Values (Left Eigenvector) = \n');
dlmwrite('DLA_GUI_Output.txt', Left_EV, 'precision', ' %.6f', '-append');

% Compute sensitivity matrix.  Write to output file, optional display.
Sensitivity = (Left_EV * Right_EV.') / (sum(Left_EV .* Right_EV));

set(handles.Sens_Matrix_Button,'UserData', Sensitivity);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nSensitivity Matrix = \n');
dlmwrite('DLA_GUI_Output.txt', Sensitivity, 'precision', ' %.6f', '-append');

% Compute elasticity matrix.  Write to output file and display.
Elasticity_Mat = 100*(Sensitivity .* A) / Lambda;
set(handles.Elas_Matrix_Button,'UserData', Elasticity_Mat);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nElasticity Matrix = \n');
dlmwrite('DLA_GUI_Output.txt', Elasticity_Mat, 'precision', ' %.6f', '-append');

% Make a column vector of elasticities. 
Elasticity_Vect = Elasticity_Mat(nzA);

% Compute the edge-loop incidence matrix using the function FindLoops on matrix A.
% Display loops as represented in Node_List.  Do not display Loop_Mat.

[Node_List,Loop_Mat] = FindLoops(A); 
%fprintf('List of all simple directed cycles in the life cycle graph and their lengths.')
Loop_Lengths = sum(Loop_Mat)';

Loop_Cell = struct2cell(Node_List);

maxsize = 0;

for i = 1:length(Loop_Cell)
    if (length(Loop_Cell{i}) > maxsize)
        maxsize = length(Loop_Cell{i});
    end    
end

maxsize = maxsize + (maxsize - 1);

Loop_Lengths = zeros(length(Loop_Cell),1);

temp = Loop_Cell{1};
l = length(temp);
Loop_Lengths(1,1) = l - 1;
Loop_List = ['Loop 1:'];
    for j = 1:l
        Loop_List = [Loop_List ' ' num2str(temp(j))];
    end    

for i = 2:length(Loop_Cell)
    temp = Loop_Cell{i};
    l = length(temp);
    Loop_Lengths(i,1) = l - 1;
    Loop_Line = ['Loop ' num2str(i) ':'];
    for j = 1:l
        Loop_Line = [Loop_Line ' ' num2str(temp(j))];
    end
    Loop_List = char(Loop_List, Loop_Line);
end    

set(handles.Loops_List_Listbox, 'String', Loop_List);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nLoops = \n');
dlmwrite('DLA_GUI_Output.txt', Loop_List, 'delimiter', ' ', 'precision', '%.6f', '-append');

% set(handles.Loops_List_Table, 'Data', Loop_List);
set(handles.Loop_Length_Table, 'Data', Loop_Lengths);

Num_Loops = length(Loop_Lengths);  % Computes number of loops.
Cycle_Space = Num_Edges - Num_Nodes + 1;  % Dimension of cycle space of A.
Solution_Set = Num_Loops - Cycle_Space;  % Dimension of the feasible solution set.

%fprintf('Dimension of cycle space, number of loops, and dim of solution set.')
[Cycle_Space Num_Loops Solution_Set];
loop_number=(1:Num_Loops)'; % Used in testing to index components of loop decompositions.

set(handles.Cycle_Space_Textbox, 'String', num2str(Cycle_Space));
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nDimension of Cycle Space = \n');
dlmwrite('DLA_GUI_Output.txt', Cycle_Space, 'precision', ' %.6f', '-append');
set(handles.Number_of_Loops_Textbox, 'String', num2str(Num_Loops));
set(handles.Number_of_Loops_Textbox, 'UserData', Num_Loops);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nNumber of Loops = \n');
dlmwrite('DLA_GUI_Output.txt', Num_Loops, 'precision', ' %.6f', '-append');
set(handles.Solution_Set_Textbox, 'String', num2str(Solution_Set));
set(handles.Solution_Set_Textbox, 'UserData', Solution_Set);
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nDimension of Solution Set = \n');
dlmwrite('DLA_GUI_Output.txt', Solution_Set, 'precision', ' %.6f', '-append');

if (Solution_Set == 0)
    x=Loop_Mat\Elasticity_Vect;  % x is the unique sol., a vector of char. elasticities.
    Unique_Decomp = [loop_number,x,x.*Loop_Lengths];
    set(handles.Unique_Decomp_Table, 'Data', Unique_Decomp)
    fclose(fid);
    fid = fopen('DLA_GUI_Output.txt', 'a');
    fprintf(fid, '\nUnique Loop Decomposition\n\nLoop Number, Characteristic Elasticities, Loop Elasticities\n');
    dlmwrite('DLA_GUI_Output.txt', Unique_Decomp, 'delimiter', '\t', 'precision', ' %.6f', '-append');
    fclose(fid);
    set(handles.Eigen_Analysis_Panel, 'Visible', 'on');
    set(handles.Loops_Panel, 'Visible', 'on');
    set(handles.Unique_Decomp_Panel, 'Visible', 'on');
    return
end

% % Find rational basis for nullspace of Loop_Mat.  
% B=null(Loop_Mat,'r');  
% 
% % Tradeoffs = zeros(Solution_Set, 3);
% %This will display tradeoffs in characteristic elasticities of loops
% for j = 1:Solution_Set
%     %     Tradeoffs (j,1) = j;
%     %     Tradeoffs (j,2) = find(B(:,j)==1)';
%     %     Tradeoffs (j,3) = find(B(:,j)==-1)';
% 
%     B_pos = find(B(:,j)==1)';
%     B_neg = find(B(:,j)==-1)';
%     TradeOffs(j)=struct('basis_vector',j,'B_pos',B_pos,'B_neg',B_neg);
%     %     TradeOffs(j)     % This dynamically displays the tradeoffs implied by B as computed.
% end
% 
% set(handles.Tradeoffs_Button,'UserData', TradeOffs);

% Now determine lower and upper bounds for characteristic and loop
% elasticities using linear programming with the Simplex algorithm.

lb = zeros(Num_Loops, 1); % Lower bound for characteristic elasticities to be used in linprog.
options1 = optimset('LargeScale', 'off', 'Simplex', 'on','Display','off'); 

char_elast=zeros(Num_Loops, 2);  % Minimum and maximum possible char. elasticities  
                        % for each loop will be stored as columns here. 
loop_elast=zeros(Num_Loops, 2);  % Minimum and maximum possible loop elasticities  
                        % for each loop will be stored as columns here. 

for i=1:Num_Loops
    f=zeros(Num_Loops, 1);
    f(i)=Loop_Lengths(i);
    x=linprog(f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
    char_elast(i,1)=x(i); % Min. char. elast. of loop i.
    x=linprog(-f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
    char_elast(i,2)=x(i); % Max. char. elast. of loop i.
end

loop_elast(:,1) = char_elast(:,1).*Loop_Lengths; % Min. loop elast. of loop i.
loop_elast(:,2) = char_elast(:,2).*Loop_Lengths; % Max. loop elast. of loop i.
% fprintf('Minimum and maximum possible loop elasticities for each loop.')
% [loop_number,loop_elast]
 
set(handles.Loop_Elas_Table, 'Data', [loop_number, loop_elast]);
Decomp = [loop_number, loop_elast];
fclose(fid);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nLoop Decomposition:\n\nLoop Number, Minimum Elasticity, Maximum Elasticity\n');
dlmwrite('DLA_GUI_Output.txt', Decomp, 'delimiter', '\t', 'precision', ' %.6f', '-append');


c = zeros(1,Num_Loops);        % c is initialized to 0. 

set(handles.C_Table, 'Data', c);

f = c.*Loop_Lengths';  % For now, we'll optimize the total loop elasticity of the selected loops.
 
[x,fval1,exitflag1]=linprog(f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
optimal_f(:,1)=x.*Loop_Lengths;
[x,fval2,exitflag2]=linprog(-f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
optimal_f(:,2)=x.*Loop_Lengths;

if ((exitflag1 ~= 1) | (exitflag2 ~= 1))
    fprintf('Did not converge to solution')
    fprintf('\n')
    fprintf('Exit flags from linprog calls are as follows')
    Exit_Flags = [exitflag1,exitflag2]
    fclose(fid);
    fid = fopen('DLA_GUI_Output.txt', 'a');
    fprintf(fid, '\nDid not converge to solution\nExit flags from linprog calls are as follows\n');
    dlmwrite('DLA_GUI_Output.txt', Exit_Flags, 'precision', ' %.6f', '-append');
end

fclose(fid);

Opti_Data = struct('Loop_Lengths', Loop_Lengths, 'Loop_Mat', Loop_Mat, 'Elasticity_Vect', Elasticity_Vect, 'lb', lb, 'options1', options1, 'loop_number', loop_number);
set(handles.Optimization_Panel, 'UserData', Opti_Data);

set(handles.Optimize_Table, 'Data', [loop_number, optimal_f]);

set(handles.Sum_Loops_Textbox, 'Visible', 'off');
set(handles.Sum_Min_Elas, 'Visible', 'off');
set(handles.Sum_Max_Elas, 'Visible', 'off');

set(handles.Loop_Elas_Panel, 'Visible', 'on');
set(handles.Eigen_Analysis_Panel, 'Visible', 'on');
set(handles.Loops_Panel, 'Visible', 'on');
set(handles.Optimization_Panel, 'Visible', 'on');

guidata(hObject, handles);

% --- Executes on button press in Optimize_Button.
function Optimize_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Optimize_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

Opti_Data = get(handles.Optimization_Panel, 'UserData');
Loop_Lengths = Opti_Data.Loop_Lengths;
Loop_Mat = Opti_Data.Loop_Mat;
Elasticity_Vect = Opti_Data.Elasticity_Vect;
lb = Opti_Data.lb;
options1 = Opti_Data.options1;
loop_number = Opti_Data.loop_number;

c = get(handles.C_Table, 'Data');
set(handles.C_Table, 'Data', []);
set(handles.C_Table, 'Data', c);

opt = find(c ~= 0);

fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nLoops being optimized =\n');
dlmwrite('DLA_GUI_Output.txt', opt, 'precision', ' %g', '-append');
fclose(fid);

f = c.*Loop_Lengths';  % For now, we'll optimize the total loop elasticity of the selected loops.
 
[x,fval1,exitflag1]=linprog(f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
optimal_f(:,1)=x.*Loop_Lengths;
[x,fval2,exitflag2]=linprog(-f,[],[],Loop_Mat,Elasticity_Vect,lb,[],[],options1);
optimal_f(:,2)=x.*Loop_Lengths;

if ((exitflag1 ~= 1) | (exitflag2 ~= 1))
    fprintf('Did not converge to solution')
    fprintf('\n')
    fprintf('Exitflags from linprog calls are as follows')
    Exit_Flags = [exitflag1,exitflag2]
    fclose(fid);
    fid = fopen('DLA_GUI_Output.txt', 'a');
    fprintf(fid, '\nDid not converge to solution\nExit flags from linprog calls are as follows\n');
    dlmwrite('DLA_GUI_Output.txt', Exit_Flags, 'precision', ' %.6f', '-append');
end

Decomp = [loop_number, optimal_f];
set(handles.Optimize_Table, 'Data', Decomp);
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nLoop Number, Minimum Elasticity, Maximum Elasticity\n');
dlmwrite('DLA_GUI_Output.txt', Decomp, 'delimiter', '\t', 'precision', ' %.6f', '-append');
fclose(fid);

%sum selected loops min and max
Sum_Min_Elas = sum(optimal_f(opt,1));
Sum_Max_Elas = sum(optimal_f(opt,2));
set(handles.Sum_Min_Elas, 'String', num2str(Sum_Min_Elas));
set(handles.Sum_Max_Elas, 'String', num2str(Sum_Max_Elas));
fid = fopen('DLA_GUI_Output.txt', 'a');
fprintf(fid, '\nSum of Minimum Elasticity and Maximum Elasticity for selected loops\n');
dlmwrite('DLA_GUI_Output.txt', Sum_Min_Elas, 'precision', ' %.6f', '-append');
dlmwrite('DLA_GUI_Output.txt', Sum_Max_Elas, 'precision', ' %.6f', '-append');
fclose(fid);
set(handles.Sum_Loops_Textbox, 'Visible', 'on');
set(handles.Sum_Min_Elas, 'Visible', 'on');
set(handles.Sum_Max_Elas, 'Visible', 'on');


guidata(hObject, handles);


% --- Executes on button press in Reset_Button.
function Reset_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Reset_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

c_length = length(get(handles.C_Table, 'Data'));

set(handles.C_Table, 'Data', zeros(1,c_length));
set(handles.Sum_Min_Elas, 'String', num2str(0));
set(handles.Sum_Max_Elas, 'String', num2str(0));

guidata(hObject, handles);



function A_Matrix_Size_Textbox_Callback(hObject, eventdata, handles)
% hObject    handle to A_Matrix_Size_Textbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of A_Matrix_Size_Textbox as text
%        str2double(get(hObject,'String')) returns contents of A_Matrix_Size_Textbox as a double
size = str2double(get(hObject, 'String'));

size = floor(size);

if (size >= 2 && size <= 100)
    set(handles.A_Matrix_Table,'Data', zeros(size));
else
    errordlg('Matrix size must be greater than 2 and less than 100', 'Error')
end
    
guidata(hObject, handles);



% --- Executes during object creation, after setting all properties.
function A_Matrix_Size_Textbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to A_Matrix_Size_Textbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in Sens_Matrix_Button.
function Sens_Matrix_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Sens_Matrix_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

S_M = get(handles.Sens_Matrix_Button, 'UserData');

sens_matrix(S_M);

% --- Executes on button press in Elas_Matrix_Button.
function Elas_Matrix_Button_Callback(hObject, eventdata, handles)
% hObject    handle to Elas_Matrix_Button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

E_M = get(handles.Elas_Matrix_Button, 'UserData');

elas_matrix(E_M)

% % --- Executes on button press in Tradeoffs_Button.
% function Tradeoffs_Button_Callback(hObject, eventdata, handles)
% % hObject    handle to Tradeoffs_Button (see GCBO)
% % eventdata  reserved - to be defined in a future version of MATLAB
% % handles    structure with handles and user data (see GUIDATA)
% 
% T_O = get(handles.Tradeoffs_Button, 'UserData');
% 
% tradeoffs(T_O)


% --- Executes on selection change in Loops_List_Listbox.
function Loops_List_Listbox_Callback(hObject, eventdata, handles)
% hObject    handle to Loops_List_Listbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns Loops_List_Listbox contents as cell array
%        contents{get(hObject,'Value')} returns selected item from Loops_List_Listbox

Sol_Set = get(handles.Solution_Set_Textbox, 'UserData');
if (Sol_Set <= 0)
    return
end

loop = get(hObject, 'Value');
C_Table = get(handles.C_Table, 'Data');
Num_Loops = get(handles.Number_of_Loops_Textbox, 'UserData');
if ((loop <= Num_Loops) & (loop >= 1))
    if (C_Table(loop) == 0)
        
        C_Table(loop) = 1;
        set(handles.C_Table, 'Data', C_Table);

    elseif (C_Table(loop) ~= 0)
        C_Table(loop) = 0;
        set(handles.C_Table, 'Data', C_Table);
    end
end    

guidata(hObject, handles);


%--- Executes during object creation, after setting all properties.
function Loops_List_Listbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to Loops_List_Listbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function Number_of_Loops_Textbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to Number_of_Loops_Textbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function Cycle_Space_Textbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to Cycle_Space_Textbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function Solution_Set_Textbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to Solution_Set_Textbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

